@@ -45,16 +45,16 @@ function(y, n, xmu.1,p.xmu, xsum.1,p.xsum, x1.1,p.x1,prior1, prec.int,
     
     if(!is.null(inits[[i]]$b)) {
       inits.internal[[i]][[1]] <- inits[[i]]$b[1]
-      inits.internal[[i]][[4]] <- matrix(rep(inits[[i]]$b[2:p.xmu],4), 
+      if(p.xmu>=2) inits.internal[[i]][[4]] <- matrix(rep(inits[[i]]$b[2:p.xmu],4), 
                                          ncol=4, byrow=FALSE)}
     if(!is.null(inits[[i]]$d)) {
       inits.internal[[i]][[2]] <- inits[[i]]$d[1]
-      inits.internal[[i]][[5]] <- matrix(rep(inits[[i]]$d[2:p.xsum],4), 
+      if(p.xsum>=2) inits.internal[[i]][[5]] <- matrix(rep(inits[[i]]$d[2:p.xsum],4), 
                                          ncol=4, byrow=FALSE)}
 
     if(!is.null(inits[[i]]$b1)) {
       inits.internal[[i]][[3]] <- inits[[i]]$b1[1]
-      inits.internal[[i]][[6]] <- matrix(rep(inits[[i]]$b1[2:p.x1],4), 
+      if(p.x1>=2) inits.internal[[i]][[6]] <- matrix(rep(inits[[i]]$b1[2:p.x1],4), 
                                          ncol=4, byrow=FALSE)}
   }  }
   op<- system.file("bugs", "fixed1.bug", package="zoib") 
