@@ -76,16 +76,19 @@ function(y, n, q, xmu.1, p.xmu, xsum.1, p.xsum,
     
     if(!is.null(inits[[i]]$b)) {
       inits.internal[[i]][[1]] <- inits[[i]]$b[1,]
-      inits.internal[[i]][[3]] <- array(rep(inits[[i]]$b[2:p.xmu,],4), c((p.xmu-1),q,4))}
+      if(p.xmu>=2) inits.internal[[i]][[3]] <- 
+        array(rep(inits[[i]]$b[2:p.xmu,],4), c((p.xmu-1),q,4))}
     if(!is.null(inits[[i]]$d)) {
       inits.internal[[i]][[2]] <- inits[[i]]$d[1,]
-      inits.internal[[i]][[4]] <- array(rep(inits[[i]]$b[2:p.xsum,],4), c((p.xsum-1),q,4))}
+      if(p.xsum>=2) inits.internal[[i]][[4]] <- 
+        array(rep(inits[[i]]$b[2:p.xsum,],4), c((p.xsum-1),q,4))}
     
     if(!is.null(inits[[i]]$sigma)) {
       inits.internal[[i]][[11]]<- inits[[i]]$sigma
       inits.internal[[i]][[12]]<- inits[[i]]$sigma
-      inits.internal[[i]][[13]]<- inits[[i]]$sigma
-      inits.internal[[i]][[14]]<- inits[[i]]$sigma}
+      inits.internal[[i]][[13]]<- runif(qz,0.25,2)
+      inits.internal[[i]][[14]]<- runif(qz,0.25,2)
+    }
     
     
     # check PD of the initial R matrix
