@@ -89,26 +89,26 @@ function(y, n, xmu.1,p.xmu, xsum.1,p.xsum, x0.1,p.x0, x1.1,p.x1,
     
     if(!is.null(inits[[i]]$b)) {
       inits.internal[[i]][[1]] <- inits[[i]]$b[1]
-      inits.internal[[i]][[5]] <- matrix(rep(inits[[i]]$b[2:p.xmu],4), 
+      if(p.xmu>=2) inits.internal[[i]][[5]] <- matrix(rep(inits[[i]]$b[2:p.xmu],4), 
                                          ncol=4, byrow=FALSE)}
     if(!is.null(inits[[i]]$d)) {
       inits.internal[[i]][[2]] <- inits[[i]]$d[1]
-    inits.internal[[i]][[6]] <- matrix(rep(inits[[i]]$d[2:p.xsum],4), 
+      if(p.xsum>=2) inits.internal[[i]][[6]] <- matrix(rep(inits[[i]]$d[2:p.xsum],4), 
                                        ncol=4, byrow=FALSE)}
     if(!is.null(inits[[i]]$b0)) {
       inits.internal[[i]][[3]] <- inits[[i]]$b0[1]
-      inits.internal[[i]][[7]] <- matrix(rep(inits[[i]]$b0[2:p.x0],4), 
+      if(p.x0>=2) inits.internal[[i]][[7]] <- matrix(rep(inits[[i]]$b0[2:p.x0],4), 
                                          ncol=4, byrow=FALSE)}
     if(!is.null(inits[[i]]$b1)) {
       inits.internal[[i]][[4]] <- inits[[i]]$b1[1]
-      inits.internal[[i]][[8]] <- matrix(rep(inits[[i]]$b1[2:p.x1],4), 
+      if(p.x1>=2) inits.internal[[i]][[8]] <- matrix(rep(inits[[i]]$b1[2:p.x1],4), 
                                          ncol=4, byrow=FALSE)}
     
     if(!is.null(inits[[i]]$sigma)) {
       inits.internal[[i]][[21]]<- inits[[i]]$sigma
       inits.internal[[i]][[22]]<- inits[[i]]$sigma
-      inits.internal[[i]][[23]]<- inits[[i]]$sigma
-      inits.internal[[i]][[24]]<- inits[[i]]$sigma
+      inits.internal[[i]][[23]]<- runif(qz,0.25,2)
+      inits.internal[[i]][[24]]<- runif(qz,0.25,2)
     }
 
     # check PD of the initial R matrix
@@ -126,18 +126,18 @@ function(y, n, xmu.1,p.xmu, xsum.1,p.xsum, x0.1,p.x0, x1.1,p.x1,
         warning('Internal initial value are used')
         break}
       else{
-        if(size==2) inits.internal[[i]][[15]] <-inits[[i]]$R[2]
+        if(size==2) inits.internal[[i]][[25]] <-inits[[i]]$R[2]
         if(size==3){
-          inits.internal[[i]][[15]] <-inits[[i]]$R[2]; 
-          inits.internal[[i]][[16]] <-inits[[i]]$R[4]; 
-          inits.internal[[i]][[17]] <-inits[[i]]$R[5]}
+          inits.internal[[i]][[25]] <-inits[[i]]$R[2]; 
+          inits.internal[[i]][[26]] <-inits[[i]]$R[4]; 
+          inits.internal[[i]][[27]] <-inits[[i]]$R[5]}
       }
-      lower <- inits.internal[[i]][[15]]*inits.internal[[i]][[16]]-
-        sqrt((1-inits.internal[[i]][[15]]^2)*(1-inits.internal[[i]][[16]]^2))
-      upper <- inits.internal[[i]][[15]]*inits.internal[[i]][[16]]+
-        sqrt((1-inits.internal[[i]][[15]]^2)*(1-inits.internal[[i]][[16]]^2))
-      if(inits.internal[[i]][[17]]<lower | inits.internal[[i]][[17]]>upper)
-        inits.internal[[i]][[17]] <- runif(1, lower, upper)
+      lower <- inits.internal[[i]][[25]]*inits.internal[[i]][[26]]-
+        sqrt((1-inits.internal[[i]][[25]]^2)*(1-inits.internal[[i]][[26]]^2))
+      upper <- inits.internal[[i]][[25]]*inits.internal[[i]][[26]]+
+        sqrt((1-inits.internal[[i]][[25]]^2)*(1-inits.internal[[i]][[26]]^2))
+      if(inits.internal[[i]][[27]]<lower | inits.internal[[i]][[27]]>upper)
+        inits.internal[[i]][[27]] <- runif(1, lower, upper)
     }
   }}
 
